import {
  createRouter,
  createWebHistory,
  RouteRecordRaw,
} from 'vue-router';
import RegisterView from '@/views/RegisterView.vue';
import LoginView from '@/views/LoginView.vue';
import { Privileges } from '@/api/types';
import HomeView from '@/views/HomeView.vue';
import FundView from '@/views/FundView.vue';
import AddFundView from '@/views/AddFundView.vue';
import hasPermission from '@/lib/auth';

const routes: Array<RouteRecordRaw> = [
  {
    path: '/',
    name: 'home',
    component: HomeView,
    meta: { title: 'Home' },
  },
  {
    path: '/fund/:id',
    name: 'fund',
    component: FundView,
    meta: { title: undefined },
  },
  {
    path: '/login',
    name: 'login',
    component: LoginView,
    meta: { title: 'Login' },
  },
  {
    path: '/register',
    name: 'register',
    component: RegisterView,
    meta: {
      requiredRights: Privileges.AdminPlus,
      title: 'Register',
    },
  },
  {
    path: '/addfund',
    name: 'addfund',
    component: AddFundView,
    meta: {
      requiredRights: Privileges.Admin,
      title: 'Add Group Fund',
    },
  },
];

const router = createRouter({
  history: createWebHistory(process.env.BASE_URL),
  routes,
});

router.beforeEach(async (to, from, next) => {
  document.title = `Beignet - ${to.meta.title}`;

  if (hasPermission(to.meta.requiredRights as number)) {
    next();
  } else {
    next('/');
  }
});

export default router;
